#[repr(u8)]pub enum Timecfg {
IF_SCL_LOW = 0,
IF_SCL_OR_SDA_LOW = 1,
}Variants
IF_SCL_LOW = 0
MSR[PLTF] sets if SCL is low for longer than the configured timeout
IF_SCL_OR_SDA_LOW = 1
MSR[PLTF] sets if either SCL or SDA is low for longer than the configured timeout
Implementations